@@ -47,7 +47,7 @@
 #endif
 
 /* Decimal number made with the formula yymmvv */
-#define ECL_VERSION_NUMBER 200424
+#define ECL_VERSION_NUMBER 210201
 
 /*
  * FEATURES LINKED IN
@@ -75,7 +75,7 @@
 #   define GC_THREADS           /* For >= 7.2 */
 # endif
 # define ECL_DYNAMIC_VV
-# include "gc.h"
+# include "gc/gc.h"
 /* GC >= 7.2 defines these macros to intercept thread functions, but
  * in doing so it breaks mingw. */
 # if defined(ECL_MS_WINDOWS_HOST) && defined(_beginthreadex)
@@ -88,8 +88,8 @@
 #undef ECL_LIBATOMIC_OPS_H
 
 /* Network streams                                                      */
-#undef TCP
-#if defined(TCP) && defined(ECL_MS_WINDOWS_HOST)
+#undef ECL_TCP
+#if defined(ECL_TCP) && defined(ECL_MS_WINDOWS_HOST)
 # define ECL_WSOCK
 #endif
 
