@@ -1,4 +1,6 @@
-/* -*- mode: c; c-basic-offset: 8 -*- */
+/* -*- Mode: C; c-basic-offset: 8; indent-tabs-mode: nil -*- */
+/* vim: set filetype=c tabstop=8 shiftwidth=4 expandtab: */
+
 /*
     ecl.h -- Main headers for development of ECL
 */
@@ -14,27 +16,31 @@
     See file '../Copyright' for full details.
 */
 
-#ifndef ECL_H
-#define ECL_H
+#ifndef ECL_ECL_H
+#define ECL_ECL_H
 
-#include <sys/types.h>		/* size_t, pthread_t, pthread_mutex_t */
-#ifdef __OpenBSD__		/* same, but for OpenBSD (bug in OpenBSD!) */
+#include <sys/types.h>          /* size_t, pthread_t, pthread_mutex_t */
+#ifdef __OpenBSD__              /* same, but for OpenBSD (bug in OpenBSD!) */
 # include <pthread.h>
 #endif
-#include <stddef.h>		/* NULL, ptrdiff_t */
-#include <stdarg.h> 		/* va_list */
-#include <setjmp.h> 		/* setjmp and buffers */
-#include <stdio.h>		/* FILE */
+#include <stddef.h>             /* NULL, ptrdiff_t */
+#include <stdarg.h>             /* va_list */
+#include <setjmp.h>             /* setjmp and buffers */
+#include <stdio.h>              /* FILE */
 /* Microsoft VC++ does not have va_copy() */
-#if defined(_MSC_VER) || !defined(va_copy)
+#if ( defined(_MSC_VER) && (_MSC_VER < 1800) ) || !defined(va_copy)
 #define va_copy(dst, src) \
    ((void) memcpy(&(dst), &(src), sizeof(va_list)))
 #endif
 
-#ifndef FIXNUM_BITS
+#ifndef ECL_FIXNUM_BITS
 #include <ecl/config.h>
 #endif
 
+#ifdef ECL_BUILD
+#include <ecl/config-internal.h>
+#endif
+
 /*
  * The Boehm-Demers-Weiser garbage collector contains wrappers for
  * dlopen and similar functions. These wrappers explicitely deactivate
@@ -51,7 +57,7 @@
 #endif
 #endif
 
-#if defined(_MSC_VER) || defined(mingw32)
+#if defined(ECL_MS_WINDOWS_HOST)
 # ifndef WIN32_LEAN_AND_MEAN
 #  define WIN32_LEAN_AND_MEAN 1 /* Do not include winsock.h */
 #  include <windows.h>
@@ -70,16 +76,20 @@
 # else
 #  error "The Windows ports cannot be built without threads."
 # endif /* ECL_THREADS */
-#endif /* _MSC_VER || mingw32 */
+#endif /* ECL_MS_WINDOWS_HOST */
+
+#ifdef ECL_SSE2
+#include <xmmintrin.h>
+#include <emmintrin.h>
+#endif
 
 #include <ecl/object.h>
 #include <ecl/external.h>
+#include <ecl/cons.h>
 #include <ecl/stacks.h>
-#include <ecl/eval.h>
 #include <ecl/number.h>
-#ifdef LOCATIVE
-#include <ecl/unify.h>
-#endif
+#include <ecl/legacy.h>
+#include <ecl/impl/math_fenv.h>
 
 typedef void (*ecl_init_function_t)(cl_object block);
 
